#! /usr/bin/env python
# -*- coding: utf-8 -*-
#
# vim: fenc=utf-8
# vim: tabstop=4 expandtab shiftwidth=4 softtabstop=4
#
#

"""



Installation
============

    pip install -U hostscli


Help
====

    Type `hostscli --help` to get a help on all the available commands


Usage
=====

**Please note that we require `sudo` permissions to change `/etc/hosts` file**

.. automodule:: hostscli.cli
    :members:
    :undoc-members:
    :show-inheritance:


Built-in utility functions
==========================

.. automodule:: hostscli.utils
    :members:
    :undoc-members:
    :show-inheritance:


Custom Errors
=============

.. automodule:: hostscli.errors
    :members:
    :undoc-members:
    :show-inheritance:


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""
